
# Dino Ai

A simple bot for automating the chrome dinosaur game 


## Documentation

### Import Name
import dino_ai

### Main class
.bot("No Parameters Required") 
###
#### Start bot
(Bot Class).start()
##### "Starts The Bot"
###
#### Misc
(Bot Class).creator
##### "returns author name"
###

(Bot Class).modules_used
##### "returns modules that were used"
###
(Bot Class).version
##### "returns version"

## Authors

- Akmal Riyas 

